@@ -1,9 +1,15 @@
 """Tests for tmuxp's helper and utility functions."""
 
+from __future__ import annotations
+
+import typing as t
+
 import pytest
-from libtmux.server import Server
 from libtmux.test import get_test_session_name, temp_session
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 
 def test_temp_session_kills_session_on_exit(server: Server) -> None:
     """Test temp_session() context manager kills session on exit."""
